@@ -72,7 +72,7 @@ def doReset(logfilename):
 
 @task()
 def combineResults(allout):
-    if not os.isdir(fetch_media_resource("Results/Buckeye")):
+    if not os.path.isdir(fetch_media_resource("Results/Buckeye")):
         os.mkdir(fetch_media_resource("Results/Buckeye"))
     with open(fetch_media_resource("Results/Buckeye/analysis.txt"),'w') as f:
         f.write("\t".join(allout[0][0].keys()))
@@ -88,7 +88,7 @@ def AnalyzeSpeaker(speaker,form):
 
 @task()
 def doBasicAnalysis(form):
-    sp = [str(x) for x in Speaker.objects.all() if str(x) != 's35']
+    sp = [x for x in Speaker.objects.all() if str(x) != 's35']
     if settings.DEBUG:
         sp = Speaker.objects.filter(Number = 's03')
         out = AnalyzeSpeaker.delay(sp[0],form)
